@@ -32,7 +32,7 @@ pub use hash::{Hash as SolderHash, ParseHashError};
 mod message;
 pub use message::{Message, MessageHeader};
 mod transaction;
-pub use transaction::{SanitizeError, Transaction};
+pub use transaction::{SanitizeError, Transaction, TransactionError};
 mod presigner;
 pub use presigner::Presigner;
 mod null_signer;
@@ -67,7 +67,12 @@ fn handle_py_value_err<T: Into<P>, E: ToString, P>(res: Result<T, E>) -> PyResul
     res.map_or_else(|e| Err(to_py_value_err(&e)), |v| Ok(v.into()))
 }
 
-create_exception!(solders, BincodeError, PyException);
+create_exception!(
+    solders,
+    BincodeError,
+    PyException,
+    "Raised when the Rust bincode library returns an error during (de)serialization."
+);
 
 impl From<Box<ErrorKind>> for PyErrWrapper {
     fn from(e: Box<ErrorKind>) -> Self {
@@ -183,6 +188,7 @@ fn solders(py: Python, m: &PyModule) -> PyResult<()> {
     let transaction_mod = PyModule::new(py, "transaction")?;
     transaction_mod.add_class::<Transaction>()?;
     transaction_mod.add("SanitizeError", py.get_type::<SanitizeError>())?;
+    transaction_mod.add("TransactionError", py.get_type::<TransactionError>())?;
     let system_program_mod = create_system_program_mod(py)?;
     let sysvar_mod = create_sysvar_mod(py)?;
     let presigner_mod = PyModule::new(py, "presigner")?;
